@@ -7,7 +7,7 @@ class Operation(ASTNode):
     def __init__(self, op, args, *args_, **kwargs):
         super().__init__(*args_, **kwargs)
 
-        self.op = op.lower()
+        self.op = ' '.join(op.lower().split())
         self.args = list(args)
         self.assert_arguments()
 
